@@ -17,13 +17,17 @@ def _get_kwargs(
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
+    schedule_path: Union[Unset, None, str] = UNSET,
     script_hash: Union[Unset, None, str] = UNSET,
-    created_before: Union[Unset, None, datetime.datetime] = UNSET,
-    created_after: Union[Unset, None, datetime.datetime] = UNSET,
+    started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    result: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/queue/list".format(client.base_url, workspace=workspace)
 
@@ -41,19 +45,21 @@ def _get_kwargs(
 
     params["script_path_start"] = script_path_start
 
+    params["schedule_path"] = schedule_path
+
     params["script_hash"] = script_hash
 
-    json_created_before: Union[Unset, None, str] = UNSET
-    if not isinstance(created_before, Unset):
-        json_created_before = created_before.isoformat() if created_before else None
+    json_started_before: Union[Unset, None, str] = UNSET
+    if not isinstance(started_before, Unset):
+        json_started_before = started_before.isoformat() if started_before else None
 
-    params["created_before"] = json_created_before
+    params["started_before"] = json_started_before
 
-    json_created_after: Union[Unset, None, str] = UNSET
-    if not isinstance(created_after, Unset):
-        json_created_after = created_after.isoformat() if created_after else None
+    json_started_after: Union[Unset, None, str] = UNSET
+    if not isinstance(started_after, Unset):
+        json_started_after = started_after.isoformat() if started_after else None
 
-    params["created_after"] = json_created_after
+    params["started_after"] = json_started_after
 
     params["success"] = success
 
@@ -63,6 +69,12 @@ def _get_kwargs(
 
     params["running"] = running
 
+    params["args"] = args
+
+    params["result"] = result
+
+    params["tag"] = tag
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -106,13 +118,17 @@ def sync_detailed(
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
+    schedule_path: Union[Unset, None, str] = UNSET,
     script_hash: Union[Unset, None, str] = UNSET,
-    created_before: Union[Unset, None, datetime.datetime] = UNSET,
-    created_after: Union[Unset, None, datetime.datetime] = UNSET,
+    started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    result: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
 ) -> Response[List[ListQueueResponse200Item]]:
     """list all available queued jobs
 
@@ -123,13 +139,17 @@ def sync_detailed(
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
+        schedule_path (Union[Unset, None, str]):
         script_hash (Union[Unset, None, str]):
-        created_before (Union[Unset, None, datetime.datetime]):
-        created_after (Union[Unset, None, datetime.datetime]):
+        started_before (Union[Unset, None, datetime.datetime]):
+        started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
+        args (Union[Unset, None, str]):
+        result (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
 
     Returns:
         Response[List[ListQueueResponse200Item]]
@@ -143,13 +163,17 @@ def sync_detailed(
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
+        schedule_path=schedule_path,
         script_hash=script_hash,
-        created_before=created_before,
-        created_after=created_after,
+        started_before=started_before,
+        started_after=started_after,
         success=success,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
+        args=args,
+        result=result,
+        tag=tag,
     )
 
     response = httpx.request(
@@ -169,13 +193,17 @@ def sync(
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
+    schedule_path: Union[Unset, None, str] = UNSET,
     script_hash: Union[Unset, None, str] = UNSET,
-    created_before: Union[Unset, None, datetime.datetime] = UNSET,
-    created_after: Union[Unset, None, datetime.datetime] = UNSET,
+    started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    result: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
 ) -> Optional[List[ListQueueResponse200Item]]:
     """list all available queued jobs
 
@@ -186,13 +214,17 @@ def sync(
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
+        schedule_path (Union[Unset, None, str]):
         script_hash (Union[Unset, None, str]):
-        created_before (Union[Unset, None, datetime.datetime]):
-        created_after (Union[Unset, None, datetime.datetime]):
+        started_before (Union[Unset, None, datetime.datetime]):
+        started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
+        args (Union[Unset, None, str]):
+        result (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
 
     Returns:
         Response[List[ListQueueResponse200Item]]
@@ -206,13 +238,17 @@ def sync(
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
+        schedule_path=schedule_path,
         script_hash=script_hash,
-        created_before=created_before,
-        created_after=created_after,
+        started_before=started_before,
+        started_after=started_after,
         success=success,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
+        args=args,
+        result=result,
+        tag=tag,
     ).parsed
 
 
@@ -225,13 +261,17 @@ async def asyncio_detailed(
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
+    schedule_path: Union[Unset, None, str] = UNSET,
     script_hash: Union[Unset, None, str] = UNSET,
-    created_before: Union[Unset, None, datetime.datetime] = UNSET,
-    created_after: Union[Unset, None, datetime.datetime] = UNSET,
+    started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    result: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
 ) -> Response[List[ListQueueResponse200Item]]:
     """list all available queued jobs
 
@@ -242,13 +282,17 @@ async def asyncio_detailed(
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
+        schedule_path (Union[Unset, None, str]):
         script_hash (Union[Unset, None, str]):
-        created_before (Union[Unset, None, datetime.datetime]):
-        created_after (Union[Unset, None, datetime.datetime]):
+        started_before (Union[Unset, None, datetime.datetime]):
+        started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
+        args (Union[Unset, None, str]):
+        result (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
 
     Returns:
         Response[List[ListQueueResponse200Item]]
@@ -262,13 +306,17 @@ async def asyncio_detailed(
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
+        schedule_path=schedule_path,
         script_hash=script_hash,
-        created_before=created_before,
-        created_after=created_after,
+        started_before=started_before,
+        started_after=started_after,
         success=success,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
+        args=args,
+        result=result,
+        tag=tag,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -286,13 +334,17 @@ async def asyncio(
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
+    schedule_path: Union[Unset, None, str] = UNSET,
     script_hash: Union[Unset, None, str] = UNSET,
-    created_before: Union[Unset, None, datetime.datetime] = UNSET,
-    created_after: Union[Unset, None, datetime.datetime] = UNSET,
+    started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    result: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
 ) -> Optional[List[ListQueueResponse200Item]]:
     """list all available queued jobs
 
@@ -303,13 +355,17 @@ async def asyncio(
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
+        schedule_path (Union[Unset, None, str]):
         script_hash (Union[Unset, None, str]):
-        created_before (Union[Unset, None, datetime.datetime]):
-        created_after (Union[Unset, None, datetime.datetime]):
+        started_before (Union[Unset, None, datetime.datetime]):
+        started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
+        args (Union[Unset, None, str]):
+        result (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
 
     Returns:
         Response[List[ListQueueResponse200Item]]
@@ -324,12 +380,16 @@ async def asyncio(
             parent_job=parent_job,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
+            schedule_path=schedule_path,
             script_hash=script_hash,
-            created_before=created_before,
-            created_after=created_after,
+            started_before=started_before,
+            started_after=started_after,
             success=success,
             job_kinds=job_kinds,
             suspended=suspended,
             running=running,
+            args=args,
+            result=result,
+            tag=tag,
         )
     ).parsed
