@@ -13,6 +13,7 @@ def _get_kwargs(
     signature: str,
     *,
     client: Client,
+    payload: Union[Unset, None, str] = UNSET,
     approver: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs_u/resume/{id}/{resume_id}/{signature}".format(
@@ -23,6 +24,8 @@ def _get_kwargs(
     cookies: Dict[str, Any] = client.get_cookies()
 
     params: Dict[str, Any] = {}
+    params["payload"] = payload
+
     params["approver"] = approver
 
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
@@ -53,6 +56,7 @@ def sync_detailed(
     signature: str,
     *,
     client: Client,
+    payload: Union[Unset, None, str] = UNSET,
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """resume a job for a suspended flow
@@ -62,6 +66,7 @@ def sync_detailed(
         id (str):
         resume_id (int):
         signature (str):
+        payload (Union[Unset, None, str]):
         approver (Union[Unset, None, str]):
 
     Returns:
@@ -74,6 +79,7 @@ def sync_detailed(
         resume_id=resume_id,
         signature=signature,
         client=client,
+        payload=payload,
         approver=approver,
     )
 
@@ -92,6 +98,7 @@ async def asyncio_detailed(
     signature: str,
     *,
     client: Client,
+    payload: Union[Unset, None, str] = UNSET,
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """resume a job for a suspended flow
@@ -101,6 +108,7 @@ async def asyncio_detailed(
         id (str):
         resume_id (int):
         signature (str):
+        payload (Union[Unset, None, str]):
         approver (Union[Unset, None, str]):
 
     Returns:
@@ -113,6 +121,7 @@ async def asyncio_detailed(
         resume_id=resume_id,
         signature=signature,
         client=client,
+        payload=payload,
         approver=approver,
     )
 
