@@ -17,6 +17,7 @@ def _get_kwargs(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run/p/{path}".format(client.base_url, workspace=workspace, path=path)
@@ -35,6 +36,8 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["job_id"] = job_id
+
     params["invisible_to_owner"] = invisible_to_owner
 
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
@@ -70,6 +73,7 @@ def sync_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run script by path
@@ -80,6 +84,7 @@ def sync_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
 
@@ -95,6 +100,7 @@ def sync_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
 
@@ -115,6 +121,7 @@ async def asyncio_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run script by path
@@ -125,6 +132,7 @@ async def asyncio_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
 
@@ -140,6 +148,7 @@ async def asyncio_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
 
