@@ -14,6 +14,7 @@ def _get_kwargs(
     json_body: RunScriptPreviewJsonBody,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run/preview".format(client.base_url, workspace=workspace)
 
@@ -25,6 +26,8 @@ def _get_kwargs(
 
     params["invisible_to_owner"] = invisible_to_owner
 
+    params["job_id"] = job_id
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -56,6 +59,7 @@ def sync_detailed(
     json_body: RunScriptPreviewJsonBody,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script preview
 
@@ -63,6 +67,7 @@ def sync_detailed(
         workspace (str):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
+        job_id (Union[Unset, None, str]):
         json_body (RunScriptPreviewJsonBody):
 
     Returns:
@@ -75,6 +80,7 @@ def sync_detailed(
         json_body=json_body,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
+        job_id=job_id,
     )
 
     response = httpx.request(
@@ -92,6 +98,7 @@ async def asyncio_detailed(
     json_body: RunScriptPreviewJsonBody,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script preview
 
@@ -99,6 +106,7 @@ async def asyncio_detailed(
         workspace (str):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
+        job_id (Union[Unset, None, str]):
         json_body (RunScriptPreviewJsonBody):
 
     Returns:
@@ -111,6 +119,7 @@ async def asyncio_detailed(
         json_body=json_body,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
+        job_id=job_id,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
