@@ -1,4 +1,3 @@
-import datetime
 from typing import Any, Dict, Union
 
 import httpx
@@ -14,10 +13,9 @@ def _get_kwargs(
     *,
     client: Client,
     json_body: RunWaitResultFlowByPathJsonBody,
-    scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, None, int] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run_wait_result/f/{path}".format(client.base_url, workspace=workspace, path=path)
 
@@ -25,18 +23,12 @@ def _get_kwargs(
     cookies: Dict[str, Any] = client.get_cookies()
 
     params: Dict[str, Any] = {}
-    json_scheduled_for: Union[Unset, None, str] = UNSET
-    if not isinstance(scheduled_for, Unset):
-        json_scheduled_for = scheduled_for.isoformat() if scheduled_for else None
-
-    params["scheduled_for"] = json_scheduled_for
-
-    params["scheduled_in_secs"] = scheduled_in_secs
-
     params["include_header"] = include_header
 
     params["queue_limit"] = queue_limit
 
+    params["job_id"] = job_id
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -67,20 +59,18 @@ def sync_detailed(
     *,
     client: Client,
     json_body: RunWaitResultFlowByPathJsonBody,
-    scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, None, int] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run flow by path and wait until completion
 
     Args:
         workspace (str):
         path (str):
-        scheduled_for (Union[Unset, None, datetime.datetime]):
-        scheduled_in_secs (Union[Unset, None, int]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
+        job_id (Union[Unset, None, str]):
         json_body (RunWaitResultFlowByPathJsonBody):
 
     Returns:
@@ -92,10 +82,9 @@ def sync_detailed(
         path=path,
         client=client,
         json_body=json_body,
-        scheduled_for=scheduled_for,
-        scheduled_in_secs=scheduled_in_secs,
         include_header=include_header,
         queue_limit=queue_limit,
+        job_id=job_id,
     )
 
     response = httpx.request(
@@ -112,20 +101,18 @@ async def asyncio_detailed(
     *,
     client: Client,
     json_body: RunWaitResultFlowByPathJsonBody,
-    scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, None, int] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
+    job_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run flow by path and wait until completion
 
     Args:
         workspace (str):
         path (str):
-        scheduled_for (Union[Unset, None, datetime.datetime]):
-        scheduled_in_secs (Union[Unset, None, int]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
+        job_id (Union[Unset, None, str]):
         json_body (RunWaitResultFlowByPathJsonBody):
 
     Returns:
@@ -137,10 +124,9 @@ async def asyncio_detailed(
         path=path,
         client=client,
         json_body=json_body,
-        scheduled_for=scheduled_for,
-        scheduled_in_secs=scheduled_in_secs,
         include_header=include_header,
         queue_limit=queue_limit,
+        job_id=job_id,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
