@@ -2,9 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.completed_job_raw_flow_failure_module_input_transforms import (
-    CompletedJobRawFlowFailureModuleInputTransforms,
-)
+from ..models.completed_job_raw_flow_failure_module_mock import CompletedJobRawFlowFailureModuleMock
 from ..models.completed_job_raw_flow_failure_module_retry import CompletedJobRawFlowFailureModuleRetry
 from ..models.completed_job_raw_flow_failure_module_sleep_type_0 import CompletedJobRawFlowFailureModuleSleepType0
 from ..models.completed_job_raw_flow_failure_module_sleep_type_1 import CompletedJobRawFlowFailureModuleSleepType1
@@ -21,20 +19,22 @@ class CompletedJobRawFlowFailureModule:
     Attributes:
         id (str):
         value (Any):
-        input_transforms (Union[Unset, CompletedJobRawFlowFailureModuleInputTransforms]):
         stop_after_if (Union[Unset, CompletedJobRawFlowFailureModuleStopAfterIf]):
         sleep (Union[CompletedJobRawFlowFailureModuleSleepType0, CompletedJobRawFlowFailureModuleSleepType1, Unset]):
+        cache_ttl (Union[Unset, float]):
         summary (Union[Unset, str]):
+        mock (Union[Unset, CompletedJobRawFlowFailureModuleMock]):
         suspend (Union[Unset, CompletedJobRawFlowFailureModuleSuspend]):
         retry (Union[Unset, CompletedJobRawFlowFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    input_transforms: Union[Unset, CompletedJobRawFlowFailureModuleInputTransforms] = UNSET
     stop_after_if: Union[Unset, CompletedJobRawFlowFailureModuleStopAfterIf] = UNSET
     sleep: Union[CompletedJobRawFlowFailureModuleSleepType0, CompletedJobRawFlowFailureModuleSleepType1, Unset] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
     summary: Union[Unset, str] = UNSET
+    mock: Union[Unset, CompletedJobRawFlowFailureModuleMock] = UNSET
     suspend: Union[Unset, CompletedJobRawFlowFailureModuleSuspend] = UNSET
     retry: Union[Unset, CompletedJobRawFlowFailureModuleRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -42,10 +42,6 @@ class CompletedJobRawFlowFailureModule:
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         value = self.value
-        input_transforms: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.input_transforms, Unset):
-            input_transforms = self.input_transforms.to_dict()
-
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
@@ -64,7 +60,12 @@ class CompletedJobRawFlowFailureModule:
             if not isinstance(self.sleep, Unset):
                 sleep = self.sleep.to_dict()
 
+        cache_ttl = self.cache_ttl
         summary = self.summary
+        mock: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.mock, Unset):
+            mock = self.mock.to_dict()
+
         suspend: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
@@ -81,14 +82,16 @@ class CompletedJobRawFlowFailureModule:
                 "value": value,
             }
         )
-        if input_transforms is not UNSET:
-            field_dict["input_transforms"] = input_transforms
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if mock is not UNSET:
+            field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
         if retry is not UNSET:
@@ -103,13 +106,6 @@ class CompletedJobRawFlowFailureModule:
 
         value = d.pop("value")
 
-        _input_transforms = d.pop("input_transforms", UNSET)
-        input_transforms: Union[Unset, CompletedJobRawFlowFailureModuleInputTransforms]
-        if isinstance(_input_transforms, Unset):
-            input_transforms = UNSET
-        else:
-            input_transforms = CompletedJobRawFlowFailureModuleInputTransforms.from_dict(_input_transforms)
-
         _stop_after_if = d.pop("stop_after_if", UNSET)
         stop_after_if: Union[Unset, CompletedJobRawFlowFailureModuleStopAfterIf]
         if isinstance(_stop_after_if, Unset):
@@ -148,8 +144,17 @@ class CompletedJobRawFlowFailureModule:
 
         sleep = _parse_sleep(d.pop("sleep", UNSET))
 
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
         summary = d.pop("summary", UNSET)
 
+        _mock = d.pop("mock", UNSET)
+        mock: Union[Unset, CompletedJobRawFlowFailureModuleMock]
+        if isinstance(_mock, Unset):
+            mock = UNSET
+        else:
+            mock = CompletedJobRawFlowFailureModuleMock.from_dict(_mock)
+
         _suspend = d.pop("suspend", UNSET)
         suspend: Union[Unset, CompletedJobRawFlowFailureModuleSuspend]
         if isinstance(_suspend, Unset):
@@ -167,10 +172,11 @@ class CompletedJobRawFlowFailureModule:
         completed_job_raw_flow_failure_module = cls(
             id=id,
             value=value,
-            input_transforms=input_transforms,
             stop_after_if=stop_after_if,
             sleep=sleep,
+            cache_ttl=cache_ttl,
             summary=summary,
+            mock=mock,
             suspend=suspend,
             retry=retry,
         )
