@@ -24,6 +24,11 @@ class CreateScriptJsonBody:
         is_template (Union[Unset, bool]):
         lock (Union[Unset, List[str]]):
         kind (Union[Unset, CreateScriptJsonBodyKind]):
+        tag (Union[Unset, str]):
+        draft_only (Union[Unset, bool]):
+        envs (Union[Unset, List[str]]):
+        concurrent_limit (Union[Unset, List[int]]):
+        concurrency_time_window_s (Union[Unset, List[int]]):
     """
 
     path: str
@@ -36,6 +41,11 @@ class CreateScriptJsonBody:
     is_template: Union[Unset, bool] = UNSET
     lock: Union[Unset, List[str]] = UNSET
     kind: Union[Unset, CreateScriptJsonBodyKind] = UNSET
+    tag: Union[Unset, str] = UNSET
+    draft_only: Union[Unset, bool] = UNSET
+    envs: Union[Unset, List[str]] = UNSET
+    concurrent_limit: Union[Unset, List[int]] = UNSET
+    concurrency_time_window_s: Union[Unset, List[int]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -59,6 +69,20 @@ class CreateScriptJsonBody:
         if not isinstance(self.kind, Unset):
             kind = self.kind.value
 
+        tag = self.tag
+        draft_only = self.draft_only
+        envs: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.envs, Unset):
+            envs = self.envs
+
+        concurrent_limit: Union[Unset, List[int]] = UNSET
+        if not isinstance(self.concurrent_limit, Unset):
+            concurrent_limit = self.concurrent_limit
+
+        concurrency_time_window_s: Union[Unset, List[int]] = UNSET
+        if not isinstance(self.concurrency_time_window_s, Unset):
+            concurrency_time_window_s = self.concurrency_time_window_s
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -80,6 +104,16 @@ class CreateScriptJsonBody:
             field_dict["lock"] = lock
         if kind is not UNSET:
             field_dict["kind"] = kind
+        if tag is not UNSET:
+            field_dict["tag"] = tag
+        if draft_only is not UNSET:
+            field_dict["draft_only"] = draft_only
+        if envs is not UNSET:
+            field_dict["envs"] = envs
+        if concurrent_limit is not UNSET:
+            field_dict["concurrent_limit"] = concurrent_limit
+        if concurrency_time_window_s is not UNSET:
+            field_dict["concurrency_time_window_s"] = concurrency_time_window_s
 
         return field_dict
 
@@ -116,6 +150,16 @@ class CreateScriptJsonBody:
         else:
             kind = CreateScriptJsonBodyKind(_kind)
 
+        tag = d.pop("tag", UNSET)
+
+        draft_only = d.pop("draft_only", UNSET)
+
+        envs = cast(List[str], d.pop("envs", UNSET))
+
+        concurrent_limit = cast(List[int], d.pop("concurrent_limit", UNSET))
+
+        concurrency_time_window_s = cast(List[int], d.pop("concurrency_time_window_s", UNSET))
+
         create_script_json_body = cls(
             path=path,
             summary=summary,
@@ -127,6 +171,11 @@ class CreateScriptJsonBody:
             is_template=is_template,
             lock=lock,
             kind=kind,
+            tag=tag,
+            draft_only=draft_only,
+            envs=envs,
+            concurrent_limit=concurrent_limit,
+            concurrency_time_window_s=concurrency_time_window_s,
         )
 
         create_script_json_body.additional_properties = d
