@@ -15,12 +15,14 @@ T = TypeVar("T", bound="ExecuteComponentJsonBody")
 class ExecuteComponentJsonBody:
     """
     Attributes:
+        component (str):
         args (Any):
         path (Union[Unset, str]):
         raw_code (Union[Unset, ExecuteComponentJsonBodyRawCode]):
         force_viewer_static_fields (Union[Unset, ExecuteComponentJsonBodyForceViewerStaticFields]):
     """
 
+    component: str
     args: Any
     path: Union[Unset, str] = UNSET
     raw_code: Union[Unset, ExecuteComponentJsonBodyRawCode] = UNSET
@@ -28,6 +30,7 @@ class ExecuteComponentJsonBody:
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        component = self.component
         args = self.args
         path = self.path
         raw_code: Union[Unset, Dict[str, Any]] = UNSET
@@ -42,6 +45,7 @@ class ExecuteComponentJsonBody:
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
+                "component": component,
                 "args": args,
             }
         )
@@ -57,6 +61,8 @@ class ExecuteComponentJsonBody:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        component = d.pop("component")
+
         args = d.pop("args")
 
         path = d.pop("path", UNSET)
@@ -78,6 +84,7 @@ class ExecuteComponentJsonBody:
             )
 
         execute_component_json_body = cls(
+            component=component,
             args=args,
             path=path,
             raw_code=raw_code,
