@@ -22,6 +22,7 @@ class FlowMetadata:
         workspace_id (Union[Unset, str]):
         additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
+        draft_only (Union[Unset, bool]):
     """
 
     path: str
@@ -32,6 +33,7 @@ class FlowMetadata:
     workspace_id: Union[Unset, str] = UNSET
     additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
+    draft_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -45,6 +47,7 @@ class FlowMetadata:
         workspace_id = self.workspace_id
         additional_properties = self.additional_properties
         starred = self.starred
+        draft_only = self.draft_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -63,6 +66,8 @@ class FlowMetadata:
             field_dict["additionalProperties"] = additional_properties
         if starred is not UNSET:
             field_dict["starred"] = starred
+        if draft_only is not UNSET:
+            field_dict["draft_only"] = draft_only
 
         return field_dict
 
@@ -85,6 +90,8 @@ class FlowMetadata:
 
         starred = d.pop("starred", UNSET)
 
+        draft_only = d.pop("draft_only", UNSET)
+
         flow_metadata = cls(
             path=path,
             edited_by=edited_by,
@@ -94,6 +101,7 @@ class FlowMetadata:
             workspace_id=workspace_id,
             additional_properties=additional_properties,
             starred=starred,
+            draft_only=draft_only,
         )
 
         flow_metadata.additional_properties = d
