@@ -6,6 +6,10 @@ class FlowModuleValue2Type0Language(str, Enum):
     PYTHON3 = "python3"
     GO = "go"
     BASH = "bash"
+    POSTGRESQL = "postgresql"
+    MYSQL = "mysql"
+    GRAPHQL = "graphql"
+    NATIVETS = "nativets"
 
     def __str__(self) -> str:
         return str(self.value)
