@@ -28,6 +28,7 @@ class GetFlowByPathResponse200:
         workspace_id (Union[Unset, str]):
         additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
+        draft_only (Union[Unset, bool]):
     """
 
     summary: str
@@ -42,6 +43,7 @@ class GetFlowByPathResponse200:
     workspace_id: Union[Unset, str] = UNSET
     additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
+    draft_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -63,6 +65,7 @@ class GetFlowByPathResponse200:
         workspace_id = self.workspace_id
         additional_properties = self.additional_properties
         starred = self.starred
+        draft_only = self.draft_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -87,6 +90,8 @@ class GetFlowByPathResponse200:
             field_dict["additionalProperties"] = additional_properties
         if starred is not UNSET:
             field_dict["starred"] = starred
+        if draft_only is not UNSET:
+            field_dict["draft_only"] = draft_only
 
         return field_dict
 
@@ -122,6 +127,8 @@ class GetFlowByPathResponse200:
 
         starred = d.pop("starred", UNSET)
 
+        draft_only = d.pop("draft_only", UNSET)
+
         get_flow_by_path_response_200 = cls(
             summary=summary,
             value=value,
@@ -135,6 +142,7 @@ class GetFlowByPathResponse200:
             workspace_id=workspace_id,
             additional_properties=additional_properties,
             starred=starred,
+            draft_only=draft_only,
         )
 
         get_flow_by_path_response_200.additional_properties = d
