@@ -37,6 +37,12 @@ class GetScriptByPathResponse200:
         schema (Union[Unset, GetScriptByPathResponse200Schema]):
         lock (Union[Unset, str]):
         lock_error_logs (Union[Unset, str]):
+        tag (Union[Unset, str]):
+        has_draft (Union[Unset, bool]):
+        draft_only (Union[Unset, bool]):
+        envs (Union[Unset, List[str]]):
+        concurrent_limit (Union[Unset, List[int]]):
+        concurrency_time_window_s (Union[Unset, List[int]]):
     """
 
     hash_: str
@@ -58,6 +64,12 @@ class GetScriptByPathResponse200:
     schema: Union[Unset, GetScriptByPathResponse200Schema] = UNSET
     lock: Union[Unset, str] = UNSET
     lock_error_logs: Union[Unset, str] = UNSET
+    tag: Union[Unset, str] = UNSET
+    has_draft: Union[Unset, bool] = UNSET
+    draft_only: Union[Unset, bool] = UNSET
+    envs: Union[Unset, List[str]] = UNSET
+    concurrent_limit: Union[Unset, List[int]] = UNSET
+    concurrency_time_window_s: Union[Unset, List[int]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -90,6 +102,20 @@ class GetScriptByPathResponse200:
 
         lock = self.lock
         lock_error_logs = self.lock_error_logs
+        tag = self.tag
+        has_draft = self.has_draft
+        draft_only = self.draft_only
+        envs: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.envs, Unset):
+            envs = self.envs
+
+        concurrent_limit: Union[Unset, List[int]] = UNSET
+        if not isinstance(self.concurrent_limit, Unset):
+            concurrent_limit = self.concurrent_limit
+
+        concurrency_time_window_s: Union[Unset, List[int]] = UNSET
+        if not isinstance(self.concurrency_time_window_s, Unset):
+            concurrency_time_window_s = self.concurrency_time_window_s
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -121,6 +147,18 @@ class GetScriptByPathResponse200:
             field_dict["lock"] = lock
         if lock_error_logs is not UNSET:
             field_dict["lock_error_logs"] = lock_error_logs
+        if tag is not UNSET:
+            field_dict["tag"] = tag
+        if has_draft is not UNSET:
+            field_dict["has_draft"] = has_draft
+        if draft_only is not UNSET:
+            field_dict["draft_only"] = draft_only
+        if envs is not UNSET:
+            field_dict["envs"] = envs
+        if concurrent_limit is not UNSET:
+            field_dict["concurrent_limit"] = concurrent_limit
+        if concurrency_time_window_s is not UNSET:
+            field_dict["concurrency_time_window_s"] = concurrency_time_window_s
 
         return field_dict
 
@@ -170,6 +208,18 @@ class GetScriptByPathResponse200:
 
         lock_error_logs = d.pop("lock_error_logs", UNSET)
 
+        tag = d.pop("tag", UNSET)
+
+        has_draft = d.pop("has_draft", UNSET)
+
+        draft_only = d.pop("draft_only", UNSET)
+
+        envs = cast(List[str], d.pop("envs", UNSET))
+
+        concurrent_limit = cast(List[int], d.pop("concurrent_limit", UNSET))
+
+        concurrency_time_window_s = cast(List[int], d.pop("concurrency_time_window_s", UNSET))
+
         get_script_by_path_response_200 = cls(
             hash_=hash_,
             path=path,
@@ -190,6 +240,12 @@ class GetScriptByPathResponse200:
             schema=schema,
             lock=lock,
             lock_error_logs=lock_error_logs,
+            tag=tag,
+            has_draft=has_draft,
+            draft_only=draft_only,
+            envs=envs,
+            concurrent_limit=concurrent_limit,
+            concurrency_time_window_s=concurrency_time_window_s,
         )
 
         get_script_by_path_response_200.additional_properties = d
