@@ -20,6 +20,9 @@ class GetSettingsResponse200:
         plan (Union[Unset, str]):
         customer_id (Union[Unset, str]):
         webhook (Union[Unset, str]):
+        deploy_to (Union[Unset, str]):
+        openai_resource_path (Union[Unset, str]):
+        error_handler (Union[Unset, str]):
     """
 
     workspace_id: Union[Unset, str] = UNSET
@@ -31,6 +34,9 @@ class GetSettingsResponse200:
     plan: Union[Unset, str] = UNSET
     customer_id: Union[Unset, str] = UNSET
     webhook: Union[Unset, str] = UNSET
+    deploy_to: Union[Unset, str] = UNSET
+    openai_resource_path: Union[Unset, str] = UNSET
+    error_handler: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -43,6 +49,9 @@ class GetSettingsResponse200:
         plan = self.plan
         customer_id = self.customer_id
         webhook = self.webhook
+        deploy_to = self.deploy_to
+        openai_resource_path = self.openai_resource_path
+        error_handler = self.error_handler
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -65,6 +74,12 @@ class GetSettingsResponse200:
             field_dict["customer_id"] = customer_id
         if webhook is not UNSET:
             field_dict["webhook"] = webhook
+        if deploy_to is not UNSET:
+            field_dict["deploy_to"] = deploy_to
+        if openai_resource_path is not UNSET:
+            field_dict["openai_resource_path"] = openai_resource_path
+        if error_handler is not UNSET:
+            field_dict["error_handler"] = error_handler
 
         return field_dict
 
@@ -89,6 +104,12 @@ class GetSettingsResponse200:
 
         webhook = d.pop("webhook", UNSET)
 
+        deploy_to = d.pop("deploy_to", UNSET)
+
+        openai_resource_path = d.pop("openai_resource_path", UNSET)
+
+        error_handler = d.pop("error_handler", UNSET)
+
         get_settings_response_200 = cls(
             workspace_id=workspace_id,
             slack_name=slack_name,
@@ -99,6 +120,9 @@ class GetSettingsResponse200:
             plan=plan,
             customer_id=customer_id,
             webhook=webhook,
+            deploy_to=deploy_to,
+            openai_resource_path=openai_resource_path,
+            error_handler=error_handler,
         )
 
         get_settings_response_200.additional_properties = d
