@@ -32,6 +32,7 @@ class ListCompletedJobsResponse200Item:
         is_skipped (bool):
         email (str):
         visible_to_owner (bool):
+        tag (str):
         workspace_id (Union[Unset, str]):
         parent_job (Union[Unset, str]):
         script_path (Union[Unset, str]):
@@ -63,6 +64,7 @@ class ListCompletedJobsResponse200Item:
     is_skipped: bool
     email: str
     visible_to_owner: bool
+    tag: str
     workspace_id: Union[Unset, str] = UNSET
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
@@ -98,6 +100,7 @@ class ListCompletedJobsResponse200Item:
         is_skipped = self.is_skipped
         email = self.email
         visible_to_owner = self.visible_to_owner
+        tag = self.tag
         workspace_id = self.workspace_id
         parent_job = self.parent_job
         script_path = self.script_path
@@ -144,6 +147,7 @@ class ListCompletedJobsResponse200Item:
                 "is_skipped": is_skipped,
                 "email": email,
                 "visible_to_owner": visible_to_owner,
+                "tag": tag,
             }
         )
         if workspace_id is not UNSET:
@@ -210,6 +214,8 @@ class ListCompletedJobsResponse200Item:
 
         visible_to_owner = d.pop("visible_to_owner")
 
+        tag = d.pop("tag")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_job = d.pop("parent_job", UNSET)
@@ -276,6 +282,7 @@ class ListCompletedJobsResponse200Item:
             is_skipped=is_skipped,
             email=email,
             visible_to_owner=visible_to_owner,
+            tag=tag,
             workspace_id=workspace_id,
             parent_job=parent_job,
             script_path=script_path,
