@@ -2,8 +2,8 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_input_transforms import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransforms,
+from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_mock import (
+    ListCompletedJobsResponse200ItemRawFlowFailureModuleMock,
 )
 from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
     ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
@@ -31,25 +31,27 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
     Attributes:
         id (str):
         value (Any):
-        input_transforms (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransforms]):
         stop_after_if (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf]):
         sleep (Union[ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
             ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1, Unset]):
+        cache_ttl (Union[Unset, float]):
         summary (Union[Unset, str]):
+        mock (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleMock]):
         suspend (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend]):
         retry (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    input_transforms: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransforms] = UNSET
     stop_after_if: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf] = UNSET
     sleep: Union[
         ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
         ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
         Unset,
     ] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
     summary: Union[Unset, str] = UNSET
+    mock: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleMock] = UNSET
     suspend: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend] = UNSET
     retry: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -57,10 +59,6 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         value = self.value
-        input_transforms: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.input_transforms, Unset):
-            input_transforms = self.input_transforms.to_dict()
-
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
@@ -79,7 +77,12 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
             if not isinstance(self.sleep, Unset):
                 sleep = self.sleep.to_dict()
 
+        cache_ttl = self.cache_ttl
         summary = self.summary
+        mock: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.mock, Unset):
+            mock = self.mock.to_dict()
+
         suspend: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
@@ -96,14 +99,16 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
                 "value": value,
             }
         )
-        if input_transforms is not UNSET:
-            field_dict["input_transforms"] = input_transforms
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if mock is not UNSET:
+            field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
         if retry is not UNSET:
@@ -118,15 +123,6 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
 
         value = d.pop("value")
 
-        _input_transforms = d.pop("input_transforms", UNSET)
-        input_transforms: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransforms]
-        if isinstance(_input_transforms, Unset):
-            input_transforms = UNSET
-        else:
-            input_transforms = ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransforms.from_dict(
-                _input_transforms
-            )
-
         _stop_after_if = d.pop("stop_after_if", UNSET)
         stop_after_if: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf]
         if isinstance(_stop_after_if, Unset):
@@ -171,8 +167,17 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
 
         sleep = _parse_sleep(d.pop("sleep", UNSET))
 
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
         summary = d.pop("summary", UNSET)
 
+        _mock = d.pop("mock", UNSET)
+        mock: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleMock]
+        if isinstance(_mock, Unset):
+            mock = UNSET
+        else:
+            mock = ListCompletedJobsResponse200ItemRawFlowFailureModuleMock.from_dict(_mock)
+
         _suspend = d.pop("suspend", UNSET)
         suspend: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend]
         if isinstance(_suspend, Unset):
@@ -190,10 +195,11 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         list_completed_jobs_response_200_item_raw_flow_failure_module = cls(
             id=id,
             value=value,
-            input_transforms=input_transforms,
             stop_after_if=stop_after_if,
             sleep=sleep,
+            cache_ttl=cache_ttl,
             summary=summary,
+            mock=mock,
             suspend=suspend,
             retry=retry,
         )
