@@ -27,6 +27,7 @@ class ListQueueResponse200Item:
         is_flow_step (bool):
         email (str):
         visible_to_owner (bool):
+        tag (str):
         workspace_id (Union[Unset, str]):
         parent_job (Union[Unset, str]):
         created_by (Union[Unset, str]):
@@ -56,6 +57,7 @@ class ListQueueResponse200Item:
     is_flow_step: bool
     email: str
     visible_to_owner: bool
+    tag: str
     workspace_id: Union[Unset, str] = UNSET
     parent_job: Union[Unset, str] = UNSET
     created_by: Union[Unset, str] = UNSET
@@ -87,6 +89,7 @@ class ListQueueResponse200Item:
         is_flow_step = self.is_flow_step
         email = self.email
         visible_to_owner = self.visible_to_owner
+        tag = self.tag
         workspace_id = self.workspace_id
         parent_job = self.parent_job
         created_by = self.created_by
@@ -143,6 +146,7 @@ class ListQueueResponse200Item:
                 "is_flow_step": is_flow_step,
                 "email": email,
                 "visible_to_owner": visible_to_owner,
+                "tag": tag,
             }
         )
         if workspace_id is not UNSET:
@@ -205,6 +209,8 @@ class ListQueueResponse200Item:
 
         visible_to_owner = d.pop("visible_to_owner")
 
+        tag = d.pop("tag")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_job = d.pop("parent_job", UNSET)
@@ -292,6 +298,7 @@ class ListQueueResponse200Item:
             is_flow_step=is_flow_step,
             email=email,
             visible_to_owner=visible_to_owner,
+            tag=tag,
             workspace_id=workspace_id,
             parent_job=parent_job,
             created_by=created_by,
