@@ -6,6 +6,11 @@ class ListQueueResponse200ItemLanguage(str, Enum):
     DENO = "deno"
     GO = "go"
     BASH = "bash"
+    POSTGRESQL = "postgresql"
+    MYSQL = "mysql"
+    GRAPHQL = "graphql"
+    NATIVETS = "nativets"
+    BUN = "bun"
 
     def __str__(self) -> str:
         return str(self.value)
