@@ -2,8 +2,8 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.list_queue_response_200_item_raw_flow_modules_item_input_transforms import (
-    ListQueueResponse200ItemRawFlowModulesItemInputTransforms,
+from ..models.list_queue_response_200_item_raw_flow_modules_item_mock import (
+    ListQueueResponse200ItemRawFlowModulesItemMock,
 )
 from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
     ListQueueResponse200ItemRawFlowModulesItemRetry,
@@ -31,25 +31,27 @@ class ListQueueResponse200ItemRawFlowModulesItem:
     Attributes:
         id (str):
         value (Any):
-        input_transforms (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemInputTransforms]):
         stop_after_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf]):
         sleep (Union[ListQueueResponse200ItemRawFlowModulesItemSleepType0,
             ListQueueResponse200ItemRawFlowModulesItemSleepType1, Unset]):
+        cache_ttl (Union[Unset, float]):
         summary (Union[Unset, str]):
+        mock (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemMock]):
         suspend (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSuspend]):
         retry (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetry]):
     """
 
     id: str
     value: Any
-    input_transforms: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemInputTransforms] = UNSET
     stop_after_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf] = UNSET
     sleep: Union[
         ListQueueResponse200ItemRawFlowModulesItemSleepType0,
         ListQueueResponse200ItemRawFlowModulesItemSleepType1,
         Unset,
     ] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
     summary: Union[Unset, str] = UNSET
+    mock: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemMock] = UNSET
     suspend: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSuspend] = UNSET
     retry: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -57,10 +59,6 @@ class ListQueueResponse200ItemRawFlowModulesItem:
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         value = self.value
-        input_transforms: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.input_transforms, Unset):
-            input_transforms = self.input_transforms.to_dict()
-
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
@@ -79,7 +77,12 @@ class ListQueueResponse200ItemRawFlowModulesItem:
             if not isinstance(self.sleep, Unset):
                 sleep = self.sleep.to_dict()
 
+        cache_ttl = self.cache_ttl
         summary = self.summary
+        mock: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.mock, Unset):
+            mock = self.mock.to_dict()
+
         suspend: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
@@ -96,14 +99,16 @@ class ListQueueResponse200ItemRawFlowModulesItem:
                 "value": value,
             }
         )
-        if input_transforms is not UNSET:
-            field_dict["input_transforms"] = input_transforms
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if mock is not UNSET:
+            field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
         if retry is not UNSET:
@@ -118,13 +123,6 @@ class ListQueueResponse200ItemRawFlowModulesItem:
 
         value = d.pop("value")
 
-        _input_transforms = d.pop("input_transforms", UNSET)
-        input_transforms: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemInputTransforms]
-        if isinstance(_input_transforms, Unset):
-            input_transforms = UNSET
-        else:
-            input_transforms = ListQueueResponse200ItemRawFlowModulesItemInputTransforms.from_dict(_input_transforms)
-
         _stop_after_if = d.pop("stop_after_if", UNSET)
         stop_after_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf]
         if isinstance(_stop_after_if, Unset):
@@ -167,8 +165,17 @@ class ListQueueResponse200ItemRawFlowModulesItem:
 
         sleep = _parse_sleep(d.pop("sleep", UNSET))
 
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
         summary = d.pop("summary", UNSET)
 
+        _mock = d.pop("mock", UNSET)
+        mock: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemMock]
+        if isinstance(_mock, Unset):
+            mock = UNSET
+        else:
+            mock = ListQueueResponse200ItemRawFlowModulesItemMock.from_dict(_mock)
+
         _suspend = d.pop("suspend", UNSET)
         suspend: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSuspend]
         if isinstance(_suspend, Unset):
@@ -186,10 +193,11 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         list_queue_response_200_item_raw_flow_modules_item = cls(
             id=id,
             value=value,
-            input_transforms=input_transforms,
             stop_after_if=stop_after_if,
             sleep=sleep,
+            cache_ttl=cache_ttl,
             summary=summary,
+            mock=mock,
             suspend=suspend,
             retry=retry,
         )
