@@ -14,31 +14,34 @@ class NewSchedule:
     Attributes:
         path (str):
         schedule (str):
+        timezone (str):
         script_path (str):
         is_flow (bool):
         args (NewScheduleArgs):
-        offset (Union[Unset, int]):
         enabled (Union[Unset, bool]):
+        on_failure (Union[Unset, str]):
     """
 
     path: str
     schedule: str
+    timezone: str
     script_path: str
     is_flow: bool
     args: NewScheduleArgs
-    offset: Union[Unset, int] = UNSET
     enabled: Union[Unset, bool] = UNSET
+    on_failure: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
         schedule = self.schedule
+        timezone = self.timezone
         script_path = self.script_path
         is_flow = self.is_flow
         args = self.args.to_dict()
 
-        offset = self.offset
         enabled = self.enabled
+        on_failure = self.on_failure
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -46,15 +49,16 @@ class NewSchedule:
             {
                 "path": path,
                 "schedule": schedule,
+                "timezone": timezone,
                 "script_path": script_path,
                 "is_flow": is_flow,
                 "args": args,
             }
         )
-        if offset is not UNSET:
-            field_dict["offset"] = offset
         if enabled is not UNSET:
             field_dict["enabled"] = enabled
+        if on_failure is not UNSET:
+            field_dict["on_failure"] = on_failure
 
         return field_dict
 
@@ -65,24 +69,27 @@ class NewSchedule:
 
         schedule = d.pop("schedule")
 
+        timezone = d.pop("timezone")
+
         script_path = d.pop("script_path")
 
         is_flow = d.pop("is_flow")
 
         args = NewScheduleArgs.from_dict(d.pop("args"))
 
-        offset = d.pop("offset", UNSET)
-
         enabled = d.pop("enabled", UNSET)
 
+        on_failure = d.pop("on_failure", UNSET)
+
         new_schedule = cls(
             path=path,
             schedule=schedule,
+            timezone=timezone,
             script_path=script_path,
             is_flow=is_flow,
             args=args,
-            offset=offset,
             enabled=enabled,
+            on_failure=on_failure,
         )
 
         new_schedule.additional_properties = d
