@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
+from ..models.open_flow_value_failure_module_suspend_resume_form import OpenFlowValueFailureModuleSuspendResumeForm
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="OpenFlowValueFailureModuleSuspend")
@@ -13,15 +14,20 @@ class OpenFlowValueFailureModuleSuspend:
     Attributes:
         required_events (Union[Unset, int]):
         timeout (Union[Unset, int]):
+        resume_form (Union[Unset, OpenFlowValueFailureModuleSuspendResumeForm]):
     """
 
     required_events: Union[Unset, int] = UNSET
     timeout: Union[Unset, int] = UNSET
+    resume_form: Union[Unset, OpenFlowValueFailureModuleSuspendResumeForm] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         required_events = self.required_events
         timeout = self.timeout
+        resume_form: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.resume_form, Unset):
+            resume_form = self.resume_form.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -30,6 +36,8 @@ class OpenFlowValueFailureModuleSuspend:
             field_dict["required_events"] = required_events
         if timeout is not UNSET:
             field_dict["timeout"] = timeout
+        if resume_form is not UNSET:
+            field_dict["resume_form"] = resume_form
 
         return field_dict
 
@@ -40,9 +48,17 @@ class OpenFlowValueFailureModuleSuspend:
 
         timeout = d.pop("timeout", UNSET)
 
+        _resume_form = d.pop("resume_form", UNSET)
+        resume_form: Union[Unset, OpenFlowValueFailureModuleSuspendResumeForm]
+        if isinstance(_resume_form, Unset):
+            resume_form = UNSET
+        else:
+            resume_form = OpenFlowValueFailureModuleSuspendResumeForm.from_dict(_resume_form)
+
         open_flow_value_failure_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
+            resume_form=resume_form,
         )
 
         open_flow_value_failure_module_suspend.additional_properties = d
