@@ -2,7 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.queued_job_raw_flow_modules_item_input_transforms import QueuedJobRawFlowModulesItemInputTransforms
+from ..models.queued_job_raw_flow_modules_item_mock import QueuedJobRawFlowModulesItemMock
 from ..models.queued_job_raw_flow_modules_item_retry import QueuedJobRawFlowModulesItemRetry
 from ..models.queued_job_raw_flow_modules_item_sleep_type_0 import QueuedJobRawFlowModulesItemSleepType0
 from ..models.queued_job_raw_flow_modules_item_sleep_type_1 import QueuedJobRawFlowModulesItemSleepType1
@@ -19,20 +19,22 @@ class QueuedJobRawFlowModulesItem:
     Attributes:
         id (str):
         value (Any):
-        input_transforms (Union[Unset, QueuedJobRawFlowModulesItemInputTransforms]):
         stop_after_if (Union[Unset, QueuedJobRawFlowModulesItemStopAfterIf]):
         sleep (Union[QueuedJobRawFlowModulesItemSleepType0, QueuedJobRawFlowModulesItemSleepType1, Unset]):
+        cache_ttl (Union[Unset, float]):
         summary (Union[Unset, str]):
+        mock (Union[Unset, QueuedJobRawFlowModulesItemMock]):
         suspend (Union[Unset, QueuedJobRawFlowModulesItemSuspend]):
         retry (Union[Unset, QueuedJobRawFlowModulesItemRetry]):
     """
 
     id: str
     value: Any
-    input_transforms: Union[Unset, QueuedJobRawFlowModulesItemInputTransforms] = UNSET
     stop_after_if: Union[Unset, QueuedJobRawFlowModulesItemStopAfterIf] = UNSET
     sleep: Union[QueuedJobRawFlowModulesItemSleepType0, QueuedJobRawFlowModulesItemSleepType1, Unset] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
     summary: Union[Unset, str] = UNSET
+    mock: Union[Unset, QueuedJobRawFlowModulesItemMock] = UNSET
     suspend: Union[Unset, QueuedJobRawFlowModulesItemSuspend] = UNSET
     retry: Union[Unset, QueuedJobRawFlowModulesItemRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -40,10 +42,6 @@ class QueuedJobRawFlowModulesItem:
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         value = self.value
-        input_transforms: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.input_transforms, Unset):
-            input_transforms = self.input_transforms.to_dict()
-
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
@@ -62,7 +60,12 @@ class QueuedJobRawFlowModulesItem:
             if not isinstance(self.sleep, Unset):
                 sleep = self.sleep.to_dict()
 
+        cache_ttl = self.cache_ttl
         summary = self.summary
+        mock: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.mock, Unset):
+            mock = self.mock.to_dict()
+
         suspend: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
@@ -79,14 +82,16 @@ class QueuedJobRawFlowModulesItem:
                 "value": value,
             }
         )
-        if input_transforms is not UNSET:
-            field_dict["input_transforms"] = input_transforms
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if mock is not UNSET:
+            field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
         if retry is not UNSET:
@@ -101,13 +106,6 @@ class QueuedJobRawFlowModulesItem:
 
         value = d.pop("value")
 
-        _input_transforms = d.pop("input_transforms", UNSET)
-        input_transforms: Union[Unset, QueuedJobRawFlowModulesItemInputTransforms]
-        if isinstance(_input_transforms, Unset):
-            input_transforms = UNSET
-        else:
-            input_transforms = QueuedJobRawFlowModulesItemInputTransforms.from_dict(_input_transforms)
-
         _stop_after_if = d.pop("stop_after_if", UNSET)
         stop_after_if: Union[Unset, QueuedJobRawFlowModulesItemStopAfterIf]
         if isinstance(_stop_after_if, Unset):
@@ -146,8 +144,17 @@ class QueuedJobRawFlowModulesItem:
 
         sleep = _parse_sleep(d.pop("sleep", UNSET))
 
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
         summary = d.pop("summary", UNSET)
 
+        _mock = d.pop("mock", UNSET)
+        mock: Union[Unset, QueuedJobRawFlowModulesItemMock]
+        if isinstance(_mock, Unset):
+            mock = UNSET
+        else:
+            mock = QueuedJobRawFlowModulesItemMock.from_dict(_mock)
+
         _suspend = d.pop("suspend", UNSET)
         suspend: Union[Unset, QueuedJobRawFlowModulesItemSuspend]
         if isinstance(_suspend, Unset):
@@ -165,10 +172,11 @@ class QueuedJobRawFlowModulesItem:
         queued_job_raw_flow_modules_item = cls(
             id=id,
             value=value,
-            input_transforms=input_transforms,
             stop_after_if=stop_after_if,
             sleep=sleep,
+            cache_ttl=cache_ttl,
             summary=summary,
+            mock=mock,
             suspend=suspend,
             retry=retry,
         )
