@@ -20,6 +20,9 @@ class RawScript:
         type (RawScriptType):
         path (Union[Unset, str]):
         lock (Union[Unset, str]):
+        tag (Union[Unset, str]):
+        concurrent_limit (Union[Unset, float]):
+        concurrency_time_window_s (Union[Unset, float]):
     """
 
     input_transforms: RawScriptInputTransforms
@@ -28,6 +31,9 @@ class RawScript:
     type: RawScriptType
     path: Union[Unset, str] = UNSET
     lock: Union[Unset, str] = UNSET
+    tag: Union[Unset, str] = UNSET
+    concurrent_limit: Union[Unset, float] = UNSET
+    concurrency_time_window_s: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -40,6 +46,9 @@ class RawScript:
 
         path = self.path
         lock = self.lock
+        tag = self.tag
+        concurrent_limit = self.concurrent_limit
+        concurrency_time_window_s = self.concurrency_time_window_s
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -55,6 +64,12 @@ class RawScript:
             field_dict["path"] = path
         if lock is not UNSET:
             field_dict["lock"] = lock
+        if tag is not UNSET:
+            field_dict["tag"] = tag
+        if concurrent_limit is not UNSET:
+            field_dict["concurrent_limit"] = concurrent_limit
+        if concurrency_time_window_s is not UNSET:
+            field_dict["concurrency_time_window_s"] = concurrency_time_window_s
 
         return field_dict
 
@@ -73,6 +88,12 @@ class RawScript:
 
         lock = d.pop("lock", UNSET)
 
+        tag = d.pop("tag", UNSET)
+
+        concurrent_limit = d.pop("concurrent_limit", UNSET)
+
+        concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
+
         raw_script = cls(
             input_transforms=input_transforms,
             content=content,
@@ -80,6 +101,9 @@ class RawScript:
             type=type,
             path=path,
             lock=lock,
+            tag=tag,
+            concurrent_limit=concurrent_limit,
+            concurrency_time_window_s=concurrency_time_window_s,
         )
 
         raw_script.additional_properties = d
