@@ -19,7 +19,7 @@ class Schedule:
         edited_by (str):
         edited_at (datetime.datetime):
         schedule (str):
-        offset (int):
+        timezone (str):
         enabled (bool):
         script_path (str):
         is_flow (bool):
@@ -27,13 +27,14 @@ class Schedule:
         email (str):
         args (Union[Unset, ScheduleArgs]):
         error (Union[Unset, str]):
+        on_failure (Union[Unset, str]):
     """
 
     path: str
     edited_by: str
     edited_at: datetime.datetime
     schedule: str
-    offset: int
+    timezone: str
     enabled: bool
     script_path: str
     is_flow: bool
@@ -41,6 +42,7 @@ class Schedule:
     email: str
     args: Union[Unset, ScheduleArgs] = UNSET
     error: Union[Unset, str] = UNSET
+    on_failure: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -49,7 +51,7 @@ class Schedule:
         edited_at = self.edited_at.isoformat()
 
         schedule = self.schedule
-        offset = self.offset
+        timezone = self.timezone
         enabled = self.enabled
         script_path = self.script_path
         is_flow = self.is_flow
@@ -61,6 +63,7 @@ class Schedule:
             args = self.args.to_dict()
 
         error = self.error
+        on_failure = self.on_failure
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -70,7 +73,7 @@ class Schedule:
                 "edited_by": edited_by,
                 "edited_at": edited_at,
                 "schedule": schedule,
-                "offset_": offset,
+                "timezone": timezone,
                 "enabled": enabled,
                 "script_path": script_path,
                 "is_flow": is_flow,
@@ -82,6 +85,8 @@ class Schedule:
             field_dict["args"] = args
         if error is not UNSET:
             field_dict["error"] = error
+        if on_failure is not UNSET:
+            field_dict["on_failure"] = on_failure
 
         return field_dict
 
@@ -96,7 +101,7 @@ class Schedule:
 
         schedule = d.pop("schedule")
 
-        offset = d.pop("offset_")
+        timezone = d.pop("timezone")
 
         enabled = d.pop("enabled")
 
@@ -117,12 +122,14 @@ class Schedule:
 
         error = d.pop("error", UNSET)
 
+        on_failure = d.pop("on_failure", UNSET)
+
         schedule = cls(
             path=path,
             edited_by=edited_by,
             edited_at=edited_at,
             schedule=schedule,
-            offset=offset,
+            timezone=timezone,
             enabled=enabled,
             script_path=script_path,
             is_flow=is_flow,
@@ -130,6 +137,7 @@ class Schedule:
             email=email,
             args=args,
             error=error,
+            on_failure=on_failure,
         )
 
         schedule.additional_properties = d
