@@ -11,46 +11,30 @@ T = TypeVar("T", bound="Usage")
 class Usage:
     """
     Attributes:
-        duration_ms (Union[Unset, int]):
-        jobs (Union[Unset, int]):
-        flows (Union[Unset, int]):
+        executions (Union[Unset, float]):
     """
 
-    duration_ms: Union[Unset, int] = UNSET
-    jobs: Union[Unset, int] = UNSET
-    flows: Union[Unset, int] = UNSET
+    executions: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        duration_ms = self.duration_ms
-        jobs = self.jobs
-        flows = self.flows
+        executions = self.executions
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
-        if duration_ms is not UNSET:
-            field_dict["duration_ms"] = duration_ms
-        if jobs is not UNSET:
-            field_dict["jobs"] = jobs
-        if flows is not UNSET:
-            field_dict["flows"] = flows
+        if executions is not UNSET:
+            field_dict["executions"] = executions
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        duration_ms = d.pop("duration_ms", UNSET)
-
-        jobs = d.pop("jobs", UNSET)
-
-        flows = d.pop("flows", UNSET)
+        executions = d.pop("executions", UNSET)
 
         usage = cls(
-            duration_ms=duration_ms,
-            jobs=jobs,
-            flows=flows,
+            executions=executions,
         )
 
         usage.additional_properties = d
