@@ -22,6 +22,7 @@ class WhoisResponse200:
         operator (bool):
         disabled (bool):
         folders (List[str]):
+        folders_owners (List[str]):
         groups (Union[Unset, List[str]]):
         usage (Union[Unset, WhoisResponse200Usage]):
     """
@@ -34,6 +35,7 @@ class WhoisResponse200:
     operator: bool
     disabled: bool
     folders: List[str]
+    folders_owners: List[str]
     groups: Union[Unset, List[str]] = UNSET
     usage: Union[Unset, WhoisResponse200Usage] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -49,6 +51,8 @@ class WhoisResponse200:
         disabled = self.disabled
         folders = self.folders
 
+        folders_owners = self.folders_owners
+
         groups: Union[Unset, List[str]] = UNSET
         if not isinstance(self.groups, Unset):
             groups = self.groups
@@ -69,6 +73,7 @@ class WhoisResponse200:
                 "operator": operator,
                 "disabled": disabled,
                 "folders": folders,
+                "folders_owners": folders_owners,
             }
         )
         if groups is not UNSET:
@@ -97,6 +102,8 @@ class WhoisResponse200:
 
         folders = cast(List[str], d.pop("folders"))
 
+        folders_owners = cast(List[str], d.pop("folders_owners"))
+
         groups = cast(List[str], d.pop("groups", UNSET))
 
         _usage = d.pop("usage", UNSET)
@@ -115,6 +122,7 @@ class WhoisResponse200:
             operator=operator,
             disabled=disabled,
             folders=folders,
+            folders_owners=folders_owners,
             groups=groups,
             usage=usage,
         )
